/*============================================================================
  File:     FreeTools_DiagnosticQueries.sql

  SQL Server Versions: 2005 onwards
------------------------------------------------------------------------------
  Written by Jonathan Kehayias, SQLskills.com
  Modified by Erin Stellato, SQLskills.com
  
  (c) 2013, SQLskills.com. All rights reserved.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  You may alter this code for your own *non-commercial* purposes. You may
  republish altered code as long as you include this copyright and give due
  credit, but you must obtain prior permission before blogging this code.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

/*
	When experiencing high CPU, use Process Explorer to find the thread
	generating the high CPU.  Enter the system thread ID in the query below
	to find information about the executing session
*/
SELECT 
	[r].[session_id], 
	[st].[text], 
	[qp].[query_plan]
FROM [sys].[dm_os_threads] [ot]
JOIN [sys].[dm_os_tasks] [t]
	ON [t].[worker_address] = [ot].[worker_address]
JOIN [sys].[dm_exec_requests] [r]
	ON [t].[session_id] = [r].[session_id]
CROSS APPLY [sys].[dm_exec_sql_text]([r].[sql_handle]) [st]
CROSS APPLY [sys].[dm_exec_query_plan]([r].[plan_handle]) [qp]
WHERE [os_thread_id] = <enter_system_thread_ID_here>


/*
	The output above includes the query plan.  If you open the query plan, use the
	Properties window to capture the query plan hash, and use in the query below
	to capture execution statistics
*/
SELECT
	[qs].[execution_count],
	[qs].[last_execution_time],
	[qs].[last_elapsed_time],
	[qs].[min_elapsed_time],
	[qs].[max_elapsed_time],
	[qs].[min_rows],
	[qs].[max_rows],
	[qs].[max_logical_reads],
	[qs].[total_logical_reads],
	[qs].[total_worker_time],
	[qp].[query_plan]
FROM [sys].[dm_exec_query_stats] [qs]
CROSS APPLY [sys].[dm_exec_sql_text]([qs].[sql_handle]) AS st
CROSS APPLY [sys].[dm_exec_query_plan]([qs].[plan_handle]) [qp]
WHERE [qs].[query_plan_hash] = <query_plan_hash_here>





